@@ -1,16 +1,20 @@
 class Location:
+    """This object shows an end
+
+    Attributes
+    ----------
+        longitude: int
+            Location longitude
+        latitude: int
+            Location latitude
+        link: str
+    """
     __slots__ = (
         "longitude",
         "latitude"
     )
 
     def __init__(self, longitude: int, latitude: int):
-        """This object shows an end
-
-        Args:
-            longitude (int): Location longitude
-            latitude (int): Location latitude
-        """
         self.longitude = longitude
         self.latitude = latitude
 
@@ -20,10 +24,6 @@ class Location:
 
     @classmethod
     def from_dict(cls, data):
-        """
-        Args:
-            data (dict): Data
-        """
         return cls(longitude=data["longitude"], latitude=data["latitude"])
 
     def to_dict(self):
