@@ -25,7 +25,7 @@ from bale.version import BALE_API_BASE_URL, BALE_API_FILE_URL
 import asyncio
 import aiohttp
 from typing import Any
-from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited)
+from ..error import (NetworkError, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError, RateLimited, HTTPException)
 from .parser import ResponseParser
 from .utils import ResponseStatusCode
 from collections import deque
@@ -172,7 +172,7 @@ class HTTPClient:
 						response: aiohttp.ClientResponse = response
 						parsed_response = await ResponseParser.from_response(response)
 						if response.status == ResponseStatusCode.NOT_FOUND:
-							raise NotFound()
+							raise NotFound(parsed_response.description)
 						elif not parsed_response.ok or response.status == ResponseStatusCode.NOT_INCORRECT:
 							if parsed_response.description == HTTPClientError.USER_OR_CHAT_NOT_FOUND:
 								raise NotFound("User or Chat not Found")
@@ -200,7 +200,9 @@ class HTTPClient:
 				except aiohttp.client_exceptions.ServerTimeoutError:
 					raise TimeOut()
 				except aiohttp.client_exceptions.ClientOSError as error:
-					raise BaleError(error)
+					raise BaleError(str(error))
+				except Exception as error:
+					raise HTTPException(error)
 
 	async def get_file(self, file_id):
 		async with self.__session.get(BALE_API_FILE_URL + "/" + "bot" + self.token + "/" + file_id) as response:
